//+------------------------------------------------------------------+
//|                                                          WSI.mq4 |
//|                             Copyright (c) 2017, Gehtsoft USA LLC | 
//|                                            http://fxcodebase.com |
//|                                   Paypal: https://goo.gl/9Rj74e  | 
//+------------------------------------------------------------------+
//|                                      Developed by : Mario Jemic  |                    
//|                                          mario.jemic@gmail.com   |
//|                   BitCoin : 15VCJTLaz12Amr7adHSBtL9v8XomURo9RF   |
//+------------------------------------------------------------------+

#property indicator_buffers 2
#property indicator_separate_window
#property indicator_width1 2
#property indicator_color1 clrLime
#property indicator_width2 2
#property indicator_color2 clrRed
#property indicator_levelcolor clrYellow
#property indicator_levelwidth 1
#property indicator_levelstyle STYLE_DOT
#property strict

extern int            CCI_Period       = 100;              // Cci period
extern int            ADX_Period       = 100;              // Adx period
extern bool           arrowsVisible    = true;             // Arrows visible?
extern bool           arrowsOnNewest   = false;            // Arrows drawn on newest bar of higher time frame bar?
extern string         arrowsIdentifier = "wsi Arrows1";    // Unique ID for arrows
extern double         arrowsUpperGap   = 1.0;              // Upper arrow gap
extern double         arrowsLowerGap   = 1.0;              // Lower arrow gap
extern color          arrowsUpColor    = clrDeepSkyBlue;   // Up arrow color
extern color          arrowsDnColor    = clrPaleVioletRed; // Down arrow color
extern int            arrowsUpCode     = 139;              // Up arrow code
extern int            arrowsDnCode     = 139;              // Down arrow code
extern bool           alertsOn         = false;            // Turn alerts on?
extern bool           alertsOnCurrent  = false;            // Alerts on still opened bar?
extern bool           alertsMessage    = true;             // Alerts should display message?
extern bool           alertsSound      = false;            // Alerts should play a sound?
extern bool           alertsNotify     = false;            // Alerts should send a notification?
extern bool           alertsEmail      = false;            // Alerts should send an email?
extern string         soundFile        = "alert2.wav";     // Sound file

double WSI[];
double Up[];
double Dn[];
double Price[];
double CCI[];
double ADX[];
double trend[];

int init(){
   
   IndicatorShortName("WSI");
   IndicatorBuffers(7);
   
   SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexBuffer(0,Up);
   SetIndexLabel(0,"WSI Up");
   SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexBuffer(1,Dn);
   SetIndexLabel(1,"WSI Down");
   
   SetIndexBuffer(2,WSI);
   SetIndexBuffer(3,Price);
   SetIndexBuffer(4,CCI);
   SetIndexBuffer(5,ADX);
   SetIndexBuffer(6,trend);
   SetLevelValue(0,0);
   return(0);
}
int deinit()
{
   string lookFor       = arrowsIdentifier+":";
   int    lookForLength = StringLen(lookFor);
   for (int i=ObjectsTotal()-1; i>=0; i--)
   {
      string objectName = ObjectName(i);
         if (StringSubstr(objectName,0,lookForLength) == lookFor) ObjectDelete(objectName);
   }
   return(0);
}


int start()
{  
  int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
   
   for(int i=limit; i>=0; i--)
   {
      
      Price[i] = iMA(NULL,0,1,0,MODE_SMA,PRICE_TYPICAL,i);
      CCI[i]   = iCCI(NULL,0,CCI_Period,PRICE_TYPICAL,i);
      ADX[i]   = iADX(NULL,0,ADX_Period,PRICE_CLOSE,MODE_MAIN,i);
      
      WSI[i]=(CCI[i]*Price[i]* ADX[i]) / 1000;
	   Up[i] = EMPTY_VALUE;
	   Dn[i] = EMPTY_VALUE;
	   if (i<Bars-1)
      {
	     trend[i] = 0;
        if (WSI[i] >= 0) trend[i] = 1;
        if (WSI[i] <  0) trend[i] =-1;
        if (trend[i] == 1) Up[i] = WSI[i];
        if (trend[i] ==-1) Dn[i] = WSI[i];
      }
       
       //
       //
       //
       //
       //
               
       if (arrowsVisible)
       {
          string lookFor = arrowsIdentifier+":"+(string)Time[i]; ObjectDelete(lookFor);            
             if (i<Bars-1 && trend[i] != trend[i+1])
             {
                if (trend[i] == 1) drawArrow(i,arrowsUpColor,arrowsUpCode,false);
                if (trend[i] ==-1) drawArrow(i,arrowsDnColor,arrowsDnCode, true);
             }
        }
   }
   
   if (alertsOn)
   {
      int whichBar = 1; if (alertsOnCurrent) whichBar = 0; 
      if (trend[whichBar] != trend[whichBar+1])
      {
         if (trend[whichBar] == 1) doAlert(" up");
         if (trend[whichBar] ==-1) doAlert(" down");       
      }         
   }   
   return(0);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(_Symbol," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," WSI ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(message);
             if (alertsEmail)   SendMail(_Symbol+" WSI ",message);
             if (alertsSound)   PlaySound(soundFile);
      }
}

//-------------------------------------------------------------------
//                                                                  
//-------------------------------------------------------------------
//
//
//
//
//

void drawArrow(int i,color theColor,int theCode,bool up)
{
   string name = arrowsIdentifier+":"+(string)Time[i];
   double gap  = iATR(NULL,0,20,i);   
   
      //
      //
      //
      //
      //

      //datetime time = Time[i]; if (arrowsOnNewest) time += _Period*60-1;      
      ObjectCreate(name,OBJ_ARROW,0,Time[i],0);
         ObjectSet(name,OBJPROP_ARROWCODE,theCode);
         ObjectSet(name,OBJPROP_COLOR,theColor);
         if (up)
               ObjectSet(name,OBJPROP_PRICE1,High[i] + arrowsUpperGap * gap);
         else  ObjectSet(name,OBJPROP_PRICE1,Low[i]  - arrowsLowerGap * gap);
}
  
